@@ -1,6 +1,7 @@
 from hdsr_wis_config_reader import IdMappingCollection
+from hdsr_wis_config_reader.idmappings.columns import IdMapColumnChoices
 from hdsr_wis_config_reader.tests.fixtures import fews_config
-from hdsr_wis_config_reader.utils import is_equal_dataframes
+from hdsr_wis_config_reader.tests.helpers import is_equal_dataframes
 
 import pandas as pd  # noqa pandas comes with geopandas
 
@@ -31,6 +32,8 @@ expected_df_b = pd.DataFrame(
     }
 )
 
+expected_ex_par_values = ["1GW", "GW1", "GW2", "GW3", "HB1", "HB2", "HB3", "HB4", "HB5", "HB6", "HB7", "HB8"]
+
 
 def test_idmapping_opvl_water(fews_config):
     id_mappings = IdMappingCollection(fews_config=fews_config)
@@ -41,6 +44,11 @@ def test_idmapping_opvl_water(fews_config):
     assert len(df_idmap_opvl_water) == 2
     assert is_equal_dataframes(expected_df=expected_df_a, test_df=df_idmap_opvl_water)
 
+    ex_par_values = id_mappings.idmap_grondwater_caw.get_filtered_column_values(
+        make_result_unique=True, target_column=IdMapColumnChoices.ex_par,
+    )
+    assert ex_par_values == expected_ex_par_values
+
     df_all = id_mappings.idmap_all.get_filtered_df(int_loc="KW761001")
     assert isinstance(df_all, pd.DataFrame)
     assert len(df_all) == 3
